<?php
/*
Plugin Name: SimpleJaeger
Description: A plugin to integrate Jaeger tracing with WordPress
Version: 1.0
Author: Colin
*/

require __DIR__ . '/vendor/autoload.php';

// Load configuration
$config = include(__DIR__ . '/simple-jaeger-config.php');

use OpenTelemetry\Sdk\Trace\TracerProvider;
use OpenTelemetry\Sdk\Trace\Exporter\JaegerExporter;
use OpenTelemetry\Sdk\Trace\SpanProcessor\SimpleSpanProcessor;

function init_simple_jaeger() {
    global $config;

    $jaeger_endpoint = $config['JAEGER_ENDPOINT'];
    $jaeger_service_name = $config['JAEGER_SERVICE_NAME'];

    $jaegerExporter = new JaegerExporter(
        $jaeger_service_name,
        $jaeger_endpoint
    );

    $tracerProvider = new TracerProvider(
        new SimpleSpanProcessor($jaegerExporter)
    );

    $tracer = $tracerProvider->getTracer('io.opentelemetry.contrib.php');

    $span = $tracer->spanBuilder('wordpress-request')->startSpan();
    $scope = $span->activate();

    $span->setAttribute('user', 'admin');

    $span->end();
    $scope->detach();
    $tracerProvider->shutdown();
}

add_action('init', 'init_simple_jaeger');
